@@ -1,7 +1,7 @@
 import typer
-from commands import oracle, pomodoro
+from timecli.commands import oracle, pomodoro
 
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 app = typer.Typer()
 app.add_typer(oracle.app, name="oracle")
